@@ -5,7 +5,6 @@ from ._base_object import _BaseObject
 
 class _Study(_BaseObject):
 	database: _Database
-
 	id: int
 	hash_id: str
 	title: str
@@ -20,15 +19,14 @@ class _Study(_BaseObject):
 
 		self.database = database
 		self.id = response['id']
-		self.hash_id = response['hash_id']
 		self.title = response['title']
 		self.authors = response['authors']
 		self.reference = response['reference']
 
 
 	def __repr__(self):
-		return 'Study(id="{}",hash_id="{}",title="{}",reference="{}")'.format(
-			self.id, self.hash_id, self.title, self.reference
+		return 'Study(id="{}",title="{}",reference="{}")'.format(
+			self.id, self.title, self.reference
 		)
 
 
