@@ -5,4 +5,7 @@ METADATA_TYPES = ['Numeric', 'Category']
 UNIT_RAW = 'raw'
 UNIT_LOGNORM = 'lognorm'
 
+EXPORT_H5AD = 'h5ad'
+EXPORT_SEURAT = 'seurat'
+
 CHUNK_SIZE = 1024 * 1024 # 1MB
